Struct prometheus::HistogramOpts [−][src]
A struct that bundles the options for creating a Histogram metric. It is
mandatory to set Name and Help to a non-empty string. All other fields are
optional and can safely be left at their zero value.
Fields
common_opts: OptsA container holding various options.
buckets: Vec<f64>Defines the buckets into which observations are counted. Each element in the slice is the upper inclusive bound of a bucket. The values must be sorted in strictly increasing order. There is no need to add a highest bucket with +Inf bound, it will be added implicitly. The default value is DefBuckets.
Implementations
Create a HistogramOpts with the name and help arguments.
const_labels sets the const labels.
const_label adds a const label.
variable_labels sets the variable labels.
variable_label adds a variable label.