Type Definition prometheus::Counter [−][src]
pub type Counter = GenericCounter<AtomicF64>;Expand description
A Metric represents a single numerical value that only ever goes up.
pub type Counter = GenericCounter<AtomicF64>;A Metric represents a single numerical value that only ever goes up.