[−][src]Struct prometheus::core::GenericGauge
Methods
impl<P: Atomic> GenericGauge<P>[src]
impl<P: Atomic> GenericGauge<P>pub fn new<S: Into<String>>(name: S, help: S) -> Result<Self> | [src] |
Create a GenericGauge with the name and help arguments.
pub fn with_opts(opts: Opts) -> Result<Self> | [src] |
Create a GenericGauge with the opts options.
pub fn set(&self, v: P::T) | [src] |
Set the gauge to an arbitrary value.
pub fn inc(&self) | [src] |
Increase the gauge by 1.
pub fn dec(&self) | [src] |
Decrease the gauge by 1.
pub fn add(&self, v: P::T) | [src] |
Add the given value to the gauge. (The value can be negative, resulting in a decrement of the gauge.)
pub fn sub(&self, v: P::T) | [src] |
Subtract the given value from the gauge. (The value can be negative, resulting in an increment of the gauge.)
pub fn get(&self) -> P::T | [src] |
Return the gauge value.